/**
 * Store details of a club membership.
 * 
 * @author David J. Barnes and Michael Kolling
 * @version 2008.03.30
 */
public class Member
{
    
    private String name;    // The name of the member.
    private int month;      // The month in which the membership was taken out.
    private int year;       // The year in which the membership was taken out.

    /**
     * Constructor for objects of class Membership.
     * This method throws an exception when it detects an error.
     * 
     * @param name The name of the member.
     * @param month The month in which they joined. (1 ... 12)
     * @param year The year in which they joined.
     */
    public Member(String name, int month, int year) throws IllegalArgumentException
    {
        if (month < 1 || month > 12)
        {
            throw new IllegalArgumentException(
                "Month " + month + " out of range. Must be in the range 1 ... 12");
        }
        this.name = name;
        this.month = month;
        this.year = year;
    }
    
    /**
     * @return The member's name.
     */
    public String getName()
    {
        return name;
    }
    
    /**
     * @return The month in which the member joined.
     *         A value in the range 1 ... 12
     */
    public int getMonth()
    {
        return month;
    }

    /**
     * @return The year in which the member joined.
     */
    public int getYear()
    {
        return year;
    }

    /**
     * toString is a special method that allows System.out.println to
     * print a class in a format that you specify.
     * 
     * @return A string representation of this membership.
     */
    public String toString()
    {
        return "Name: " + name + " joined in month " + month + " of " + year;
    }
}
